@@ -4,7 +4,7 @@ BEGIN {
 	die "Encode::TW not supported on EBCDIC\n";
     }
 }
-our $VERSION = do { my @r = (q$Revision: 1.22 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+our $VERSION = do { my @r = (q$Revision: 1.23 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 use Encode;
 use XSLoader;
@@ -30,10 +30,10 @@ Encodings supported are as follows.
 
   Canonical   Alias		Description
   --------------------------------------------------------------------
-  big5        /\bbig-?5$/i	The original Big5 encoding
-  big5-hkscs  /\bbig5-hk(scs)?$/i
-                                Big5 plus Cantonese characters in 
-                                Hong Kong
+  big5-eten   /\bbig-?5$/i	Big5 encoding (with ETen extensions)
+	      /\bbig5-?et(en)?$/i
+  big5-hkscs  /\bbig5-?hk(scs)?$/i
+                                Big5 + Cantonese characters in Hong Kong
   MacChineseSimp		Big5 + Apple Vendor Mappings
   cp950		                Code Page 950 
                                 = Big5 + Microsoft vendor mappings
@@ -44,12 +44,19 @@ To find how to use this module in detail, see L<Encode>.
 =head1 NOTES
 
 Due to size concerns, C<EUC-TW> (Extended Unix Character), C<CCCII>
-(Chinese Character Code for Information Interchange) and C<BIG5PLUS>
-(CMEX's Big5+) are distributed separately on CPAN, under the name
-L<Encode::HanExtra>. That module also contains extra China-based encodings.
+(Chinese Character Code for Information Interchange), C<BIG5PLUS>
+(CMEX's Big5+) and C<BIG5EXT> (CMEX's Big5e) are distributed separately
+on CPAN, under the name L<Encode::HanExtra>. That module also contains
+extra China-based encodings.
 
 =head1 BUGS
 
+Since the original C<big5> encoding (1984) is not supported anywhere
+(glibc and DOS-based systems uses C<big5> to mean C<big5-eten>; Microsoft
+uses C<big5> to mean C<cp950>), a concious decision was made to alias
+C<big5> to C<big5-eten>, which is the de facto superset of the original
+big5.
+
 The C<CNS11643> encoding files are not complete. For common C<CNS11643>
 manipulation, please use C<EUC-TW> in L<Encode::HanExtra>, which contains
 plane 1-7.
