@@ -1,14 +1,15 @@
 package Encode::JP::JIS7;
 use strict;
 
-our $VERSION = do { my @r = (q$Revision: 1.2 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+our $VERSION = do { my @r = (q$Revision: 1.3 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+
+use Encode qw(:fallbacks);
 
-require Encode;
 for my $name ('7bit-jis', 'iso-2022-jp', 'iso-2022-jp-1'){
     my $h2z     = ($name eq '7bit-jis')    ? 0 : 1;
     my $jis0212 = ($name eq 'iso-2022-jp') ? 0 : 1;
-    
-    $Encode::Encoding{$name} =  
+
+    $Encode::Encoding{$name} =
         bless {
                Name      =>   $name,
                h2z       =>   $h2z,
@@ -17,7 +18,10 @@ for my $name ('7bit-jis', 'iso-2022-jp', 'iso-2022-jp-1'){
 }
 
 sub name { shift->{'Name'} }
-sub new_sequence { $_[0] };
+
+sub new_sequence { $_[0] }
+
+sub needs_lines { 1 }
 
 use Encode::CJKConstants qw(:all);
 
@@ -27,28 +31,28 @@ our $DEBUG = 0;
 # decode is identical for all 2022 variants
 #
 
-sub decode
+sub decode($$;$)
 {
     my ($obj,$str,$chk) = @_;
     my $residue = jis_euc(\$str);
     # This is for PerlIO
     $_[1] = $residue if $chk;
     # use perlqq fallback for euc-jp -> utf8
-    return Encode::decode('euc-jp', $str, 0);
+    return Encode::decode('euc-jp', $str, FB_PERLQQ);
 }
 
 #
 # encode is different
 #
 
-sub encode
+sub encode($$;$)
 {
     require Encode::JP::H2Z;
     my ($obj, $utf8, $chk) = @_;
     # empty the input string in the stack so perlio is ok
     $_[1] = '' if $chk;
     my ($h2z, $jis0212) = @$obj{qw(h2z jis0212)};
-    my $octet = Encode::encode('euc-jp', $utf8, 0) ;
+    my $octet = Encode::encode('euc-jp', $utf8, FB_PERLQQ) ;
     $h2z and &Encode::JP::H2Z::h2z(\$octet);
     euc_jis(\$octet, $jis0212);
     return $octet;
@@ -87,7 +91,7 @@ sub euc_jis{
 	((?:$RE{EUC_C})+|(?:$RE{EUC_KANA})+|(?:$RE{EUC_0212})+)
 	}{
 	    my $chunk = $1;
-	    my $esc = 
+	    my $esc =
 		( $chunk =~ tr/\x8E//d ) ? $ESC{KANA} :
 		    ( $chunk =~ tr/\x8F//d ) ? $ESC{JIS_0212} :
 			$ESC{JIS_0208};
